<?php

class M_Imagely_Braintree extends C_Base_Module
{
    function define($id = 'pope-module',
                    $name = 'Pope Module',
                    $description = '',
                    $version = '',
                    $uri = '',
                    $author = '',
                    $author_uri = '',
                    $context = FALSE)
    {
        parent::define(
            'imagely-braintree',
            'Braintree',
            'Provides integration with Braintree payment gateway',
            '3.21.0',
            'https://www.imagely.com/wordpress-gallery-plugin/nextgen-pro/',
            'Imagely',
            'https://www.imagely.com'
        );

        C_Photocrati_Installer::add_handler('imagely-braintree', 'C_Braintree_Installer');
    }

    function _register_adapters()
    {
        if (!$this->php_version_check())
            return;

        if (is_admin())
            $this->get_registry()->add_adapter('I_Form', 'A_Braintree_Form', NGG_PRO_PAYMENT_GATEWAY_FORM);

        $this->get_registry()->add_adapter('I_NextGen_Pro_Checkout', 'A_Braintree_Button');
    }

    function _register_hooks()
    {
        if (!$this->php_version_check())
            return;

        add_filter('ngg_pro_settings_reset_installers', [$this, 'return_own_installer']);
        add_filter('ngg_pro_lab_test_mode',             [$this, 'use_print_lab_test_service'], 10, 2);

        add_action('rest_api_init', ['C_Braintree_Rest', 'rest_api_init_action']);

        $requirements = C_Admin_Requirements_Manager::get_instance();
        $requirements->add(
            'braintree_curl_requirement',
            'phpext',
            [$this, 'check_curl_requirement'],
            ['message' => __('cURL is required for Braintree support to function', 'nextgen-gallery-pro')]
        );
        $requirements->add(
            'braintree_php_version_requirement',
            'phpver',
            [$this, 'php_version_check'],
            ['message' => __('PHP 7.3.0 is required for Braintree to function. Your settings have been preserved but Braintree will remain disabled until your PHP version is upgraded to at least 7.3.0.', 'nextgen-gallery-pro')]
        );
    }

    /**
     * @param bool $use_test_mode
     * @param C_NextGen_Pro_Order $order
     * @return bool
     */
    function use_print_lab_test_service($use_test_mode = FALSE, $order = NULL)
    {
        $settings = C_NextGen_Settings::get_instance();
        return ($order->payment_gateway === 'braintree' && $settings->get('ecommerce_braintree_sandbox')) ? TRUE : $use_test_mode;
    }

    public function php_version_check()
    {
        if (version_compare(PHP_VERSION, '7.3.0', '<'))
            return FALSE;
        return TRUE;
    }

    public function check_curl_requirement()
    {
        return function_exists('curl_init');
    }

    public function return_own_installer($installers)
    {
        $installers[] = 'C_Braintree_Installer';
        return $installers;
    }

    function get_type_list()
    {
        return [
            'A_Braintree_Button' => 'adapter.button.php',
            'A_Braintree_Form'   => 'adapter.form.php',
            'C_Braintree_Rest'   => 'class.rest.php'
        ];
    }
}

class C_Braintree_Installer extends AC_NextGen_Pro_Settings_Installer
{
    function __construct()
    {
        $this->set_defaults(array(
            'ecommerce_braintree_enable'           => '0',
            'ecommerce_braintree_sandbox'          => '1',
            'ecommerce_braintree_public_key'       => '',
            'ecommerce_braintree_private_key'      => '',
            'ecommerce_braintree_merchant_id'      => '',
            'ecommerce_braintree_enable_paypal'    => '0',
            'ecommerce_braintree_pass_client_data' => '0'
        ));

        $this->set_groups(array('ecommerce'));
    }
}

new M_Imagely_Braintree();
