<?php
class A_Braintree_Button extends Mixin
{
    public static $client_token_generated;
    function get_checkout_buttons()
    {
        $buttons = parent::call_parent('get_checkout_buttons');
        if ($this->is_braintree_enabled()) {
            $buttons[] = 'braintree';
        }
        return $buttons;
    }
    function is_braintree_enabled()
    {
        return C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable');
    }
    public function enqueue_braintree_resources()
    {
        $settings = C_NextGen_Settings::get_instance();
        $gateway = new Braintree\Gateway(['environment' => $settings->get('ecommerce_braintree_sandbox') ? 'sandbox' : 'production', 'merchantId' => $settings->get('ecommerce_braintree_merchant_id'), 'publicKey' => $settings->get('ecommerce_braintree_public_key'), 'privateKey' => $settings->get('ecommerce_braintree_private_key')]);
        $client_token = $gateway->clientToken()->generate();
        M_Gallery_Display::enqueue_fontawesome();
        wp_enqueue_script('braintree', 'https://js.braintreegateway.com/web/dropin/1.36.0/js/dropin.js', [], '1.36.0', TRUE);
        wp_enqueue_script('nextgen_pro_braintree_js', $this->object->get_static_url('imagely-braintree#button.js'), ['braintree', 'fontawesome', 'jquery'], FALSE, TRUE);
        wp_enqueue_style('nextgen_pro_braintree_css', $this->object->get_static_url('imagely-braintree#button.css'), [], FALSE);
        try {
            wp_localize_script('nextgen_pro_braintree_js', 'nextgen_pro_braintree_data', ['client_token' => $client_token, 'pass_client_data' => (bool) $settings->get('ecommerce_braintree_pass_client_data'), 'enable_paypal' => (bool) $settings->get('ecommerce_braintree_enable_paypal'), 'currency' => C_NextGen_Pro_Currencies::$currencies[$settings->get('ecommerce_currency')]['code'], 'rest_url' => rest_url() . 'ngg-pro/v1/payment-gateways/braintree']);
            self::$client_token_generated = TRUE;
        } catch (\Braintree\Exception\Authentication $exception) {
            self::$client_token_generated = FALSE;
            error_log(home_url() . ": NextGEN Gallery cannot authenticate with Braintree to provide its checkout button");
        } catch (Exception $exception) {
            self::$client_token_generated = FALSE;
        }
    }
    /**
     * @return stdClass
     */
    function get_i18n_strings()
    {
        $i18n = $this->call_parent('get_i18n_strings');
        $i18n->cancel_payment = __('Cancel', 'nextgen-gallery-pro');
        $i18n->choose_payment_method = __('Choose method', 'nextgen-gallery-pro');
        $i18n->pay_with_card = __('Pay with Card', 'nextgen-gallery-pro');
        $i18n->submit_in_progress = __('Processing...', 'nextgen-gallery-pro');
        $i18n->submit_payment = __('Submit order', 'nextgen-gallery-pro');
        return $i18n;
    }
    /**
     * @return string
     */
    function _render_braintree_button()
    {
        if (!self::$client_token_generated) {
            return '';
        }
        $settings = C_NextGen_Settings::get_instance();
        return $this->object->render_partial('imagely-braintree#button', ['paypal_enabled' => (bool) $settings->get('ecommerce_braintree_enable_paypal'), 'i18n' => $this->get_i18n_strings()], TRUE);
    }
}
class A_Braintree_Form extends Mixin
{
    function _get_field_names()
    {
        $fields = $this->call_parent('_get_field_names');
        $fields[] = 'nextgen_pro_ecommerce_braintree_enable';
        $fields[] = 'nextgen_pro_ecommerce_braintree_sandbox';
        $fields[] = 'nextgen_pro_ecommerce_braintree_merchant_id';
        $fields[] = 'nextgen_pro_ecommerce_braintree_public_key';
        $fields[] = 'nextgen_pro_ecommerce_braintree_private_key';
        $fields[] = 'nextgen_pro_ecommerce_braintree_enable_paypal';
        $fields[] = 'nextgen_pro_ecommerce_braintree_pass_client_data';
        $fields[] = 'nextgen_pro_ecommerce_braintree_instructions';
        return $fields;
    }
    function enqueue_static_resources()
    {
        $this->call_parent('enqueue_static_resources');
        wp_enqueue_script('ngg_pro_braintree_form_js', $this->object->get_static_url('imagely-braintree#form.js'), ['jquery']);
    }
    function _render_nextgen_pro_ecommerce_braintree_enable_field($model)
    {
        $model = new stdClass();
        $model->name = 'ecommerce';
        return $this->object->_render_radio_field($model, 'braintree_enable', __('Enable Braintree', 'nextgen-gallery-pro'), C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable'), __('Not all currencies are supported by all payment gateways. Please be sure to confirm your desired currency is supported by Braintree', 'nextgen-gallery-pro'));
    }
    function _render_nextgen_pro_ecommerce_braintree_sandbox_field()
    {
        $model = new stdClass();
        $model->name = 'ecommerce';
        return $this->object->_render_radio_field($model, 'braintree_sandbox', __('Use Sandbox', 'nextgen-gallery-pro'), C_NextGen_Settings::get_instance()->get('ecommerce_braintree_sandbox'), '', !C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable'));
    }
    function _render_nextgen_pro_ecommerce_braintree_public_key_field($model)
    {
        $model = new stdClass();
        $model->name = 'ecommerce';
        return $this->object->_render_text_field($model, 'braintree_public_key', __('<strong>Public key</strong>', 'nextgen-gallery-pro'), C_NextGen_Settings::get_instance()->get('ecommerce_braintree_public_key'), '', !C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable'));
    }
    function _render_nextgen_pro_ecommerce_braintree_private_key_field($model)
    {
        $model = new stdClass();
        $model->name = 'ecommerce';
        return $this->object->_render_text_field($model, 'braintree_private_key', __('<strong>Private key</strong>', 'nextgen-gallery-pro'), C_NextGen_Settings::get_instance()->get('ecommerce_braintree_private_key'), '', !C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable'));
    }
    function _render_nextgen_pro_ecommerce_braintree_merchant_id_field($model)
    {
        $model = new stdClass();
        $model->name = 'ecommerce';
        return $this->object->_render_text_field($model, 'braintree_merchant_id', __('<strong>Merchant ID</strong>', 'nextgen-gallery-pro'), C_NextGen_Settings::get_instance()->get('ecommerce_braintree_merchant_id'), '', !C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable'));
    }
    public function _render_nextgen_pro_ecommerce_braintree_enable_paypal_field($model)
    {
        $model = new stdClass();
        $model->name = 'ecommerce';
        return $this->object->_render_radio_field($model, 'braintree_enable_paypal', __('Enable PayPal payments', 'nextgen-gallery-pro'), C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable_paypal'), __('PayPal is not enabled by default and must be configured first in your Brainree account.', 'nextgen-gallery-pro'), !C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable'));
    }
    public function _render_nextgen_pro_ecommerce_braintree_pass_client_data_field($model)
    {
        $model = new stdClass();
        $model->name = 'ecommerce';
        return $this->object->_render_radio_field($model, 'braintree_pass_client_data', __('Send browser data to Braintree', 'nextgen-gallery-pro'), C_NextGen_Settings::get_instance()->get('ecommerce_braintree_pass_client_data'), __('Braintree recommends that transactions include customer browser data for their fraud detection tools. Consult the Braintree Data Protection Addendum for more information regarding your own data protection compliance.', 'nextgen-gallery-pro'), !C_NextGen_Settings::get_instance()->get('ecommerce_braintree_enable'));
    }
    public function _render_nextgen_pro_ecommerce_braintree_instructions_field($model)
    {
        $settings = C_NextGen_Settings::get_instance();
        $url = 'https://www.imagely.com/docs/how-to-setup-braintree-checkout/';
        $i18n = ['setup_instructions' => sprintf(__('See our <a href="%s" target="_blank"">documentation</a> on setting up Braintree.', 'nextgen-gallery-pro'), $url)];
        return $this->object->render_partial('imagely-braintree#admin_instructions', ['i18n' => $i18n, 'hidden' => !$settings->get('ecommerce_braintree_enable')], TRUE);
    }
}
class C_Braintree_Rest extends WP_REST_Controller
{
    public $namespace = 'ngg-pro/v1';
    public $rest_base = 'payment-gateways';
    public static function rest_api_init_action()
    {
        $self = new self();
        \register_rest_route($self->namespace, '/' . $self->rest_base . '/braintree', ['args' => ['nonce' => ['type' => 'string', 'required' => TRUE], 'client_data' => ['type' => 'string', 'required' => (bool) C_NextGen_Settings::get_instance()->get('ecommerce_braintree_pass_client_data')], 'cart' => ['type' => 'string', 'required' => TRUE]], ['methods' => \WP_REST_SERVER::CREATABLE, 'callback' => [$self, 'CreateOrder'], 'permission_callback' => '__return_true']]);
    }
    /**
     * @param WP_REST_Request $request
     * @return WP_REST_Response
     */
    public function CreateOrder($request)
    {
        $retval = [];
        $checkout = new C_NextGen_Pro_Checkout();
        $settings = C_NextGen_Settings::get_instance();
        try {
            /** @var array $cart */
            parse_str($request->get_param('cart'), $cart);
            $ngg_order_result = $checkout->save_order($cart['settings'], $cart['items'], $cart['coupon'], 'awaiting_payment', 'braintree', __('Order submitted to BrainTree for processing', 'nextgen-gallery-pro'), FALSE);
            /** @var C_NextGen_Pro_Cart $cart */
            $cart = $ngg_order_result['cart'];
            $gateway = new Braintree\Gateway(['environment' => $settings->get('ecommerce_braintree_sandbox') ? 'sandbox' : 'production', 'merchantId' => $settings->get('ecommerce_braintree_merchant_id'), 'publicKey' => $settings->get('ecommerce_braintree_public_key'), 'privateKey' => $settings->get('ecommerce_braintree_private_key')]);
            $sale = ['amount' => $cart->get_total(), 'paymentMethodNonce' => $request->get_param('nonce'), 'options' => ['submitForSettlement' => TRUE]];
            $client_data = $request->get_param('client_data');
            if ($client_data && $settings->get('ecommerce_braintree_pass_client_data')) {
                $sale['deviceData'] = $client_data;
            }
            $braintree_result = $gateway->transaction()->sale($sale);
            if ($braintree_result->success) {
                // $checkout->save_order() returns an array that does not include the order object itself, just an ID
                $order_mapper = C_Order_Mapper::get_instance();
                $order = $order_mapper->find_by_hash($ngg_order_result['order'], TRUE);
                $order->braintree_transaction_id = $braintree_result->transaction->id;
                // $checkout->mark_as_paid() will save() the $order
                $checkout->mark_as_paid($order, TRUE, TRUE, __('Payment has been processed by Braintree, no further work is required.', 'nextgen-gallery-pro'));
                $checkout->send_order_notification($order);
                $retval['status'] = 'success';
                $retval['confirmation_url'] = $ngg_order_result['redirect'];
            } else {
                if ($braintree_result->transaction) {
                    $transaction = $braintree_result->transaction;
                    $retval['status'] = 'failure';
                    $retval['errors'] = [];
                    $retval['errors'][$transaction->processorResponseCode] = $transaction->processorResponseText;
                } else {
                    $retval['status'] = 'failure';
                    $retval['errors'] = [];
                    foreach ($braintree_result->errors->deepAll() as $error) {
                        $retval['errors'][] = [$error->code => $error->message];
                    }
                }
            }
        } catch (Exception $error) {
            $retval['status'] = 'errors';
            $retval['errors'] = [];
            $retval['errors'][500] = $error->getMessage();
        }
        return new WP_REST_Response($retval);
    }
}